@@ -41,7 +41,6 @@ describe 'basic designate' do
             rabbit_password     => 'an_even_bigger_secret',
             rabbit_host         => '127.0.0.1',
             debug               => true,
-            verbose             => true,
           }
           class { '::designate::api':
             enabled           => true,
@@ -55,7 +54,7 @@ describe 'basic designate' do
           include ::designate::client
           class { '::designate::agent': }
           class { '::designate::db':
-            database_connection => 'mysql://designate:a_big_secret@127.0.0.1/designate?charset=utf8',
+            database_connection => 'mysql+pymysql://designate:a_big_secret@127.0.0.1/designate?charset=utf8',
           }
           include ::designate::dns
         }
